@@ -1296,7 +1296,11 @@ static void handle_folder_popup(HildonFileChooserDialog *self)
       HildonFileChooserDialogPrivate *sub_priv =
         HILDON_FILE_CHOOSER_DIALOG (dialog)->priv;
 
-      g_assert(sub_priv->create_folder_handle == NULL);
+      if (sub_priv->create_folder_handle)
+        {
+	  gtk_file_system_cancel_operation (sub_priv->create_folder_handle);
+	  sub_priv->create_folder_handle = NULL;
+	}
 
       /* Callback is quaranteed to be called, it unrefs the object data */
       sub_priv->create_folder_handle =
